@@ -74,7 +74,7 @@ class action_plugin_fckg_edit extends DokuWiki_Action_Plugin {
              }
         }
 
-        $Using_FCKG_EDITOR = true;
+        // $Using_FCKG_EDITOR = true;
         $controller->register_hook('TPL_ACT_RENDER', 'BEFORE', $this, 'fckg_edit');
         $controller->register_hook('TPL_METAHEADER_OUTPUT', 'BEFORE', $this, 'fckg_edit_meta');
     }
@@ -124,7 +124,7 @@ class action_plugin_fckg_edit extends DokuWiki_Action_Plugin {
         global $REV;
         global $INFO;
         if(!isset($INFO['userinfo'])) {
-           return;
+        //   return;
         }
         global $WASSHOW;
         // load the text and check if it is a fck
@@ -258,16 +258,38 @@ class action_plugin_fckg_edit extends DokuWiki_Action_Plugin {
             $ro='readonly="readonly"';
         }
         if(!$DATE) $DATE = $INFO['lastmod'];
-        echo  $this->helper->registerOnLoad(
-            'var fck = new FCKeditor("wiki__text", "100%", "600"); 
-             fck.BasePath = "'.DOKU_BASE.'lib/plugins/fckg/'.$this->fck_location.'/"; 
-             fck.ToolbarSet = "Dokuwiki";  
-             fck.ReplaceTextarea();'
-             );
-// $temp=array();
-// trigger_event('HTML_EDITFORM_INJECTION', $temp);
-// print_r($_REQUEST);
-$Using_FCKG_EDITOR = true;  
+         if(!$DATE) $DATE = $INFO['lastmod'];
+        $guest_toolbar = $this->getConf('guest_toolbar');
+        $guest_media  = $this->getConf('guest_media');
+        if(!isset($INFO['userinfo']) && !$guest_toolbar) {        
+            
+                echo  $this->helper->registerOnLoad(
+                    ' fck = new FCKeditor("wiki__text", "100%", "600"); 
+                     fck.BasePath = "'.DOKU_BASE.'lib/plugins/fckg/'.$this->fck_location.'/"; 
+                     fck.ToolbarSet = "DokuwikiNoGuest";  
+                     fck.ReplaceTextarea();'
+                     );
+        }
+        else if(!isset($INFO['userinfo']) && !$guest_media) {            
+
+            echo  $this->helper->registerOnLoad(
+                ' fck = new FCKeditor("wiki__text", "100%", "600"); 
+                 fck.BasePath = "'.DOKU_BASE.'lib/plugins/fckg/'.$this->fck_location.'/"; 
+                 fck.ToolbarSet = "DokuwikiGuest";  
+                 fck.ReplaceTextarea();'
+                 );
+        }
+        
+        else {
+            echo  $this->helper->registerOnLoad(
+                ' fck = new FCKeditor("wiki__text", "100%", "600"); 
+                 fck.BasePath = "'.DOKU_BASE.'lib/plugins/fckg/'.$this->fck_location.'/"; 
+                 fck.ToolbarSet = "Dokuwiki";  
+                 fck.ReplaceTextarea();'
+                 );
+        }
+
+ 
 ?>
 
    <form id="dw__editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>"><div class="no">
@@ -298,6 +320,17 @@ if($INFO['client'] == 'guest') $DW_EDIT_disabled = 'disabled';
 
     <div id="wiki__editbar">
       <div id="size__ctl"></div>
+      <div id = "fck_size__ctl" style="display: none">
+       
+       <img src = "<?php echo DOKU_BASE ?>lib/images/smaller.gif"
+                    title="edit window smaller"
+                    onclick="dwfck_size_ctl('smaller');"   
+                    >
+       <img src = "<?php echo DOKU_BASE ?>lib/images/larger.gif"
+                    title="edit window larger"
+                    onclick="dwfck_size_ctl('larger');"   
+           >
+      </div>
       <?php if($wr){?>
          <div class="editButtons">
             <input type="checkbox" name="fckg" value="fckg" checked="checked" style="display: none;"/>
@@ -325,7 +358,7 @@ $users = trim($users);
 if(strtoupper($users) == 'ANY') {
     $disabled = '';
 }
-else {
+elseif(isset($INFO['userinfo'])) {
   $user_groups = $INFO['userinfo']['grps'];
   $allowed_groups = explode(',',$users);
   foreach($allowed_groups as $group) {
@@ -345,12 +378,15 @@ if($this->big_file()) {
 $FCK_PREVIEW_DISPLAY = "";
 
 $fck_preview = $this->getConf('fck_preview');
-if(in_array($fck_preview, $INFO['userinfo']['grps'])) {  
-   $FCK_PREVIEW_DISPLAY = ' style="display:inline"; ';
+if(isset($INFO['userinfo'])) {
+    if(in_array($fck_preview, $INFO['userinfo']['grps'])) {  
+       $FCK_PREVIEW_DISPLAY = ' style="display:inline"; ';
+    }
 }
-
 ?>
-<input class="button" type="submit" name="do[draftdel]" value="<?php echo $lang['btn_cancel']?>" tabindex="8" />
+            <input class="button" type="submit" name="do[draftdel]"
+             value="<?php echo $lang['btn_cancel']?>" tabindex="8" 
+            />
 
             <input class="button" id="edbtn__preview" type="submit" name="do[preview]"  
                      <?php echo $DW_EDIT_disabled; ?>
@@ -390,15 +426,13 @@ if(in_array($fck_preview, $INFO['userinfo']['grps'])) {
                               onmouseup="document.getElementById('fck_convert').checked=false;"
                               title="Your work will be saved as <?php echo $this->fckg_bak_file ?>"
                              /> Backup FCK and open blank editor&nbsp;&nbsp;&nbsp;&nbsp;
-
- <br/ ><!--  td-->
+ <br/ >
 <input type="checkbox" name="fckg_timer" value="fckg_timer"  id = "fckg_timer"
-                      style = display:none;'
+                      style = 'display:none;'
                       onclick="disableDokuWikiLockTimer();";  <?php echo $disabled  ?>
                 / > <span id='fckg_timer_label'
                     style = 'display:none;'>Disable editor time-out messsages </span> 
-<!--/table -->
-       
+     
 
   <script language="javascript">
         function aspell_window() {
@@ -421,8 +455,10 @@ if(in_array($fck_preview, $INFO['userinfo']['grps'])) {
 
   var dwform = $('dw__editform');
   var text = dwform.elements.wikitext.value;
+
   var pre = text.indexOf('<pre');  
-  var table = text.indexOf('<table');  
+  // var table = text.indexOf('<table');  
+  var table = -1;   // these conversions no longer needed for table ?
   if(pre != -1 || table != -1) {
       text = text.replace(/\n/g, "__NL___");  // string replace balks at newlines
       if(pre != -1) {
@@ -437,19 +473,45 @@ if(in_array($fck_preview, $INFO['userinfo']['grps'])) {
 
 function repl_cb(one,two,three,four) {
 // one is the entire match
+
    var code = one.match(/<pre/) ? true : false;
-   three.replace(/_<(.*?)_>/g,"<$1>")
-   three = three.replace(/</g,'&lt;')
+
+    three = three.replace(/<a(?=\s)/g,'__openURL__');
+    three = three.replace(/<\/a>/g,'__closedURL__'); 
+ 
+   //three = three.replace(/_<([^\<]+)_>/g,"<$1>");
+   three = three.replace(/</g,'&lt;')   
    three = three.replace(/>/g,'&gt;')
-   three = three.replace(/&lt;([biu]{1,1})&gt;/g,'<$1>') 
-   three = three.replace(/&lt;\/([biu]{1,1})&gt;/g,'</$1>') 
+
    if(!code) {
-       three = three.replace(/&lt;br \/&gt;/g,'<br />'); 
-       three = three.replace(/&lt;(strong|em)&gt;/g,'<$1>'); 
-       three = three.replace(/&lt;\/(strong|em)&gt;/g,'<\/$1>'); 
+      three = three.replace(/&lt;([biu]{1,1})&gt;/g,'<$1>') ;
+      three = three.replace(/&lt;\/([biu]{1,1})&gt;/g,'</$1>') ;
+      three = three.replace(/&lt;br \/&gt;/g,'<br />'); 
+      three = three.replace(/&lt;(strong|em|strike|del|sup|sub)&gt;/g,'<$1>'); 
+      three = three.replace(/&lt;\/(strong|em|strike|del|sup|sub)&gt;/g,'<\/$1>');   
    }
-   var str =  two + three + four;
-   return  str;
+   else {
+       three = three.replace(/fckgOpenPAREN/g,'&lt;');
+       three = three.replace(/&lt;em&gt;(\\+)&lt;\/em&gt;/g,'<em>$1</em>');
+   }
+
+    three = three.replace(/__openURL__/g,'<a');
+    three = three.replace(/__closedURL__/g,'</a>');
+
+    var str =  two + three + four;
+    return  str;
+}
+
+function dwfck_size_ctl(which) {
+   var height = parseInt(document.getElementById('wiki__text___Frame').style.height); 
+   if(which == 'smaller') {
+       height -= 50;
+   }
+   else {
+      height += 50;
+   }
+   document.getElementById('wiki__text___Frame').style.height = height + 'px'; 
+   
 }
   </script>
 
@@ -550,8 +612,11 @@ function repl_cb(one,two,three,four) {
      $text = preg_replace('/<font _dummy_\/.*?courier New>(.*?)<\/font>/ms', "''$1''", $text);  
      $text = preg_replace('/<align\s+left>(?!\\{2})\s*/ms', "\\\\\\\\  ", $text);  
      $text = preg_replace('/<align\s+0px>\s*/ms', "\\\\\\\\ ", $text);  
-     $text = preg_replace('/&nbsp;/ms', " ", $text);  //  remove &nbsp;     
+     $text = preg_replace('/&nbsp;/ms', " ", $text);  //  remove &nbsp;    
+     $text = preg_replace('/<(?=\w+@.*?>)/ms', "&lt;", $text);   
      $text =  strip_tags($text, '<code>,<del>');
+     $text = preg_replace('/&lt;(?=\w+@.*?>)/ms', "<", $text);  
+   
     
    
      $text = preg_replace_callback(
@@ -569,14 +634,14 @@ function repl_cb(one,two,three,four) {
            "trim_code_escapes",
           $text
       );  
-
+     $text = preg_replace('/\|\+\+THEAD\+\+ ALIGN=\w+\|\|/',"",$text);
      // process td's
      $text = preg_replace_callback(
           '/\|(.*?)\|/ms',
            "trim_code_escapes",
           $text
       );  
-    
+   
     io_SaveFile($event->data[0][0], $text);  
 
   }
@@ -645,8 +710,8 @@ function trim_fck_align_cell($align, $str) {
      $text = str_replace('fckgCodeBLOCK', "", $text);
      $text = str_replace('fckgOpenPAREN', '<', $text);    
      $text = str_replace("%%", "", $text);
-     $text = str_replace('fckgTableOpenBRACKET', "<", $text);     
-
+     $text = str_replace('fckgTableOpenBRACKET', "<", $text);   
+     
      return $text;
   }
 ?>
