@@ -247,16 +247,6 @@ BUT;
 
       var dwform = $('dw__editform');
 
-      if(e.id) {
-         if(e.id == 'edbtn__edit' && which == 1) {
-           if(!window.confirm(
-               "You will lose any edits made in this preview window")
-               ) {
- 
-                   return false;
-                 }
-         }
-      }
       if(dwform && dwform.elements && dwform.elements.recovery) {           
            dwform.elements.recovery.value = dwform.elements.wikitext.value; 
       }
