@@ -42,7 +42,11 @@ FCKConfig.StartupShowBlocks = false ;
 FCKConfig.Debug = false ;
 FCKConfig.AllowQueryStringDebug = true ;
 
-FCKConfig.SkinPath = FCKConfig.BasePath + 'skins/default/' ;
+FCKConfig.SkinPath = FCKConfig.BasePath + 'skins/silver/' ;
+
+FCKConfig.SkinEditorCSS = '' ;	// FCKConfig.SkinPath + "|<minified css>" ;
+FCKConfig.SkinDialogCSS = '' ;	// FCKConfig.SkinPath + "|<minified css>" ;
+
 FCKConfig.PreloadImages = [ FCKConfig.SkinPath + 'images/toolbar.start.gif', FCKConfig.SkinPath + 'images/toolbar.buttonarrow.gif' ] ;
 
 FCKConfig.PluginsPath = FCKConfig.BasePath + 'plugins/' ;
@@ -71,7 +75,10 @@ FCKConfig.FormatSource		= true ;
 FCKConfig.FormatOutput		= true ;
 FCKConfig.FormatIndentator	= '    ' ;
 
-FCKConfig.GeckoUseSPAN	= false ;
+FCKConfig.EMailProtection = 'none' ; // none | encode | function
+FCKConfig.EMailProtectionFunction = 'mt(NAME,DOMAIN,SUBJECT,BODY)' ;
+
+//FCKConfig.GeckoUseSPAN	= false ;
 FCKConfig.StartupFocus	= false ;
 FCKConfig.ForcePasteAsPlainText	= false ;
 FCKConfig.AutoDetectPasteFromWord = true ;	// IE only.
@@ -83,7 +90,7 @@ FCKConfig.SourcePopup	= true ;
 FCKConfig.ToolbarStartExpanded	= true ;
 FCKConfig.ToolbarCanCollapse	= true ;
 FCKConfig.IgnoreEmptyParagraphValue = true ;
-FCKConfig.PreserveSessionOnFileBrowser = false ;
+//FCKConfig.PreserveSessionOnFileBrowser = false ;
 FCKConfig.FloatingPanelsZIndex = 10000 ;
 FCKConfig.HtmlEncodeOutput = false ;
 
@@ -98,8 +105,9 @@ FCKConfig.Plugins.Add('trim') ;
 FCKConfig.Plugins.Add('blockquote') ;
 FCKConfig.Plugins.Add('plugintool', 'en,fr,nl') ;
 FCKConfig.Plugins.Add( 'paradelete' ) ;
-FCKConfig.Plugins.Add( 'autogrow' ) ;
+// FCKConfig.Plugins.Add( 'autogrow' ) ;
 FCKConfig.Plugins.Add( 'range' ) ;
+FCKConfig.Plugins.Add( 'breakdel' ) ;
 
 
 FCKConfig.ToolbarSets["Default"] = [
@@ -109,7 +117,7 @@ FCKConfig.ToolbarSets["Default"] = [
 	['Form','Checkbox','Radio','TextField','Textarea','Select','Button','ImageButton','HiddenField'],
 	'/',
 	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
-	['OrderedList','UnorderedList','-','Outdent','Indent','Blockquote'],
+	['OrderedList','UnorderedList','-','Outdent','Indent','Blockquote','CreateDiv'],
 	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
 	['Link','Unlink','Anchor'],
 	['Image','Flash','Table','Rule','Smiley','SpecialChar','PageBreak'],
@@ -131,8 +139,10 @@ FCKConfig.Keystrokes = [
 	[ CTRL + 67 /*C*/, true ],
 	[ CTRL + 70 /*F*/, true ],
 	[ CTRL + 83 /*S*/, true ],
+	[ CTRL + 84 /*T*/, true ],
 	[ CTRL + 88 /*X*/, true ],
 	[ CTRL + 86 /*V*/, 'Paste' ],
+	[ CTRL + 45 /*INS*/, true ],
 	[ SHIFT + 45 /*INS*/, 'Paste' ],
 	[ CTRL + 88 /*X*/, 'Cut' ],
 	[ SHIFT + 46 /*DEL*/, 'Cut' ],
@@ -145,16 +155,17 @@ FCKConfig.Keystrokes = [
 	[ CTRL + 85 /*U*/, 'Underline' ],
 	[ CTRL + SHIFT + 83 /*S*/, 'Save' ],
 	[ CTRL + ALT + 13 /*ENTER*/, 'FitWindow' ],
-	[ CTRL + 9 /*TAB*/, 'Source' ]
+	[ SHIFT + 32 /*SPACE*/, 'Nbsp' ]
 ] ;
 
 FCKConfig.ContextMenu = ['Generic','Link','Anchor','Image','Flash','Select','Textarea','Checkbox','Radio','TextField','HiddenField','ImageButton','Button','BulletedList','NumberedList','Table','Form'] ;
 FCKConfig.BrowserContextMenuOnCtrl = false ;
+FCKConfig.BrowserContextMenu = false ;
 
 FCKConfig.EnableMoreFontColors = true ;
 FCKConfig.FontColors = '000000,993300,333300,003300,003366,000080,333399,333333,800000,FF6600,808000,808080,008080,0000FF,666699,808080,FF0000,FF9900,99CC00,339966,33CCCC,3366FF,800080,999999,FF00FF,FFCC00,FFFF00,00FF00,00FFFF,00CCFF,993366,C0C0C0,FF99CC,FFCC99,FFFF99,CCFFCC,CCFFFF,99CCFF,CC99FF,FFFFFF' ;
 
-FCKConfig.FontFormats	= 'p;h1;h2;h3;h4;h5;h6;pre;address;div';
+FCKConfig.FontFormats	= 'p;h1;h2;h3;h4;h5';  // code
 FCKConfig.FontNames		= 'Arial;Comic Sans MS;Courier New;Tahoma;Times New Roman;Verdana;Gill Sans,Gill Sans MT,Arial;Copperplate Gothic Light,CopperplateLight;Baskerville,Baskerville Old Face;Lucida Bright;Palatino, Palatino Linotype';
 //FCKConfig.FontSizes		= 'smaller;larger;xx-small;x-small;small;medium;large;x-large;xx-large' ;
 FCKConfig.FontSizes		= '6pt;8pt;9pt;10pt;11pt;12pt;14pt;16pt;18pt;24pt;36pt' ;
@@ -184,7 +195,7 @@ FCKConfig.FlashDlgHideAdvanced	= false ;
 FCKConfig.ProtectedTags = 'indent' ;
 FCKConfig.ProtectedTags = 'header' ;
 FCKConfig.ProtectedTags = 'plugin' ;
-FCKConfig.ProtectedTags = 'redact' ;   // possible substitution for indent in editor window with IE, which messes up ident
+FCKConfig.ProtectedTags = 'fckg' ;   
 
 // This will be applied to the body element of the editor
 FCKConfig.BodyId = '' ;
@@ -203,6 +214,9 @@ FCKConfig.CleanWordKeepsStructure = false ;
 // Only inline elements are valid.
 FCKConfig.RemoveFormatTags = 'b,big,code,del,dfn,em,font,i,ins,kbd,q,samp,small,span,strike,strong,sub,sup,tt,u,var' ;
 
+// Attributes that will be removed
+FCKConfig.RemoveAttributes = 'class,style,lang,width,height,align,hspace,valign' ;
+
 FCKConfig.CustomStyles = 
 {
 //	'Red Title'	: { Element : 'h3', Styles : { 'color' : 'Red' } }
@@ -218,6 +232,7 @@ FCKConfig.CoreStyles =
 	'StrikeThrough'	: { Element : 'strike' },
 	'Subscript'		: { Element : 'sub' },
 	'Superscript'	: { Element : 'sup' },
+
 	
 	// Basic Block Styles (Font Format Combo).
 	'p'				: { Element : 'p' },
@@ -230,6 +245,7 @@ FCKConfig.CoreStyles =
 	'h4'			: { Element : 'h4' },
 	'h5'			: { Element : 'h5' },
 	'h6'			: { Element : 'h6' },
+	'code'                  : { Element : 'code' },
  
 	// Other formatting features.
 	'FontFace' : 
@@ -253,9 +269,12 @@ FCKConfig.CoreStyles =
 		Overrides	: [ { Element : 'font', Attributes : { 'color' : null } } ]
 	},
 	
-	'BackColor'		: { Element : 'span', Styles : { 'background-color' : '#("Color","color")' } }
+	'BackColor'		: { Element : 'span', Styles : { 'background-color' : '#("Color","color")' } },
+
+	'SelectionHighlight' : { Element : 'span', Styles : { 'background-color' : 'navy', 'color' : 'white' } }
 };
 
+//FCKConfig.CoreStyles['Code'] = { Element : 'code' };
 // The distance of an indentation step.
 FCKConfig.IndentLength = 40 ;
 FCKConfig.IndentUnit = 'px' ;
@@ -283,17 +302,17 @@ var _FileBrowserExtension = _FileBrowserLanguage == 'perl' ? 'cgi' : _FileBrowse
 var _QuickUploadExtension = _QuickUploadLanguage == 'perl' ? 'cgi' : _QuickUploadLanguage ;
 
 FCKConfig.LinkBrowser = true ;
-FCKConfig.LinkBrowserURL = FCKConfig.BasePath + 'filemanager/browser/default/browser.html?Connector=../../connectors/' + _FileBrowserLanguage + '/connector.' + _FileBrowserExtension ;
+FCKConfig.LinkBrowserURL = FCKConfig.BasePath + 'filemanager/browser/default/browser.html?Connector=' + encodeURIComponent( FCKConfig.BasePath + 'filemanager/connectors/' + _FileBrowserLanguage + '/connector.' + _FileBrowserExtension ) ;
 FCKConfig.LinkBrowserWindowWidth	= FCKConfig.ScreenWidth * 0.7 ;		// 70%
 FCKConfig.LinkBrowserWindowHeight	= FCKConfig.ScreenHeight * 0.7 ;	// 70%
 
 FCKConfig.ImageBrowser = true ;
-FCKConfig.ImageBrowserURL = FCKConfig.BasePath + 'filemanager/browser/default/browser.html?Type=Image&Connector=../../connectors/' + _FileBrowserLanguage + '/connector.' + _FileBrowserExtension ;
+FCKConfig.ImageBrowserURL = FCKConfig.BasePath + 'filemanager/browser/default/browser.html?Type=Image&Connector=' + encodeURIComponent( FCKConfig.BasePath + 'filemanager/connectors/' + _FileBrowserLanguage + '/connector.' + _FileBrowserExtension ) ;
 FCKConfig.ImageBrowserWindowWidth  = FCKConfig.ScreenWidth * 0.7 ;	// 70% ;
 FCKConfig.ImageBrowserWindowHeight = FCKConfig.ScreenHeight * 0.7 ;	// 70% ;
 
 FCKConfig.FlashBrowser = true ;
-FCKConfig.FlashBrowserURL = FCKConfig.BasePath + 'filemanager/browser/default/browser.html?Type=Flash&Connector=../../connectors/' + _FileBrowserLanguage + '/connector.' + _FileBrowserExtension ;
+FCKConfig.FlashBrowserURL = FCKConfig.BasePath + 'filemanager/browser/default/browser.html?Type=Flash&Connector=' + encodeURIComponent( FCKConfig.BasePath + 'filemanager/connectors/' + _FileBrowserLanguage + '/connector.' + _FileBrowserExtension ) ;
 FCKConfig.FlashBrowserWindowWidth  = FCKConfig.ScreenWidth * 0.7 ;	//70% ;
 FCKConfig.FlashBrowserWindowHeight = FCKConfig.ScreenHeight * 0.7 ;	//70% ;
 
@@ -318,20 +337,36 @@ FCKConfig.SmileyColumns = 8 ;
 FCKConfig.SmileyWindowWidth		= 320 ;
 FCKConfig.SmileyWindowHeight	= 240 ;
 
-
-FCKConfig.ToolbarSets["Dokuwiki"] = [   
-  ['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],   
-  ['OrderedList','UnorderedList'],  ['Outdent','Indent'],   
-  ['JustifyCenter','JustifyLeft','JustifyRight'],
-  ['Rule', 'Block_Q'], ['Smiley', 'SpecialChar'], [],  
-  ['Cut','Copy','Paste','PasteText', 'PasteWord', 'SpellCheck', 'Find'],   
-  ['Style'], ['FontFormat','FontName','FontSize'], 
-  ['Undo','Redo','RemoveFormat', '-','Table','Format_Table'],   
-  ['TextColor','BGColor', 'Plugin_Tool', 'Trim_Spaces','Delete_P'],
-  ['Link','Unlink'], ['Image', 'Source' ],   
+FCKConfig.ToolbarSets["DokuwikiNoGuest"] = [  
+  ['Source' ], 
   ['About']  
 ] ;  
 
+FCKConfig.ToolbarSets["DokuwikiGuest"] = [   
+  ['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],   
+  ['OrderedList','UnorderedList'],
+  ['Rule', 'Smiley', 'SpecialChar', 'Style'], [],  
+  ['Cut','Copy','Paste','PasteText', 'SpellCheck', 'Find'],   
+  ['FontFormat'], ['Undo','Redo','RemoveFormat', '-','Table' ],   
+  ['Plugin_Tool',  'Delete_P' ],
+  ['Source' ],   
+  ['About']  
+] ;  
+
+FCKConfig.ToolbarSets["Dokuwiki"] = [
+  ['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
+  ['OrderedList','UnorderedList'],  ['Outdent','Indent'],
+  ['JustifyCenter','JustifyLeft','JustifyRight'],
+  ['Rule', 'Block_Q'], ['Smiley', 'SpecialChar'], [],
+  ['Cut','Copy','Paste','PasteText', 'PasteWord', 'SpellCheck', 'Find'],
+  ['Style'], ['FontFormat','FontName','FontSize'],
+  ['Undo','Redo','RemoveFormat', '-','Table','Format_Table'],
+  ['TextColor','BGColor', 'Plugin_Tool', 'Trim_Spaces','Delete_P', 'Delete_BR'],
+  ['Link','Unlink'], ['Image', 'Source' ],['FitWindow'],
+  ['About']
+] ;
+
+
 FCK.getCurrentWikiNS = function () {
  var ns = "";
  if(top.getCurrentWikiNS) {
@@ -341,3 +376,10 @@ FCK.getCurrentWikiNS = function () {
   return ns;
 }
 
+FCKConfig.BackgroundBlockerColor = '#ffffff' ;
+FCKConfig.BackgroundBlockerOpacity = 0.50 ;
+
+FCKConfig.MsWebBrowserControlCompat = false ;
+
+FCKConfig.PreventSubmitHandler = false ;
+
