@@ -21,7 +21,7 @@ use  HTML::Entities;
 use Params::Validate ':types';
 
 
-our $VERSION = '0.29';
+our $VERSION = '0.31';
 
   my $SPACEBAR_NUDGING = 0;
   my  $color_pattern = qr/
@@ -85,6 +85,7 @@ sub new {
   $self->{'colspan'} = "";
   $self->{'code'} = 0;
   $self->{'block'} = 0;
+  $self->{'share'} = 0;
   $self->{'do_nudge'} = $SPACEBAR_NUDGING;
 
   if(!$self->{'do_nudge'}) {
@@ -93,6 +94,7 @@ sub new {
   $self->{'err'} = "NOERR\n";
   $self->{'_fh'} = 0;  # turn off debugging
   # $self->{'_fh'} = getFH();
+  $self->{'os'} = $^O;
   return $self;
 }
 
@@ -102,6 +104,7 @@ sub new {
 sub getFH {
   my($self) =  @_;
   local *FH; 
+  #  if(open(FH, '>> C:\\Windows\\Temp\\fckg.log')) { 
   if(open(FH, ">> /var/tmp/fckg.log")) {
      return *FH;
   }
@@ -154,8 +157,8 @@ sub rules {
     $rules->{"h$_"} = { replace => \&_header };
   }
   $rules->{'plugin'} = { replace => \&_plugin};
-  $rules->{ 'table' } = { start =>"<align left></align>", end => "<align left><br /></align>" };
- 
+ # $rules->{ 'table' } = { start =>"<align left></align>", end => "<align left><br /></align>" };
+  $rules->{ 'table' } = { replace => \&_table };
   $rules->{'ins'} = { alias => 'u'};
   $rules->{'b'} = { replace => \&_formats };
   $rules->{'i'} = { replace => \&_formats };
@@ -173,10 +176,16 @@ sub _formats {
 
     my $text = $self->get_elem_contents($node);
 
-    $text = $self->trim($text);
+  # $text = $self->trim($text);
     return "" if ! $text; 
-    return "" if $text !~ /[\p{IsDigit}\p{IsAlpha}\p{IsXDigit}]/;
+    return "" if $text !~ /[\p{IsDigit}\p{IsAlpha}\p{IsXDigit}\\]/;
 
+    my @count = $text =~ /\\/g;
+    if(scalar @count) {
+      my $count = scalar @count;
+      $text =  "_<em_>fckgBACKSLASH_<em_>" x $count;
+      return $text;
+    }
     $text =~ s/^$_format_regex{$node->tag}//;
     $text =~ s/$_format_regex{$node->tag}$//;
     
@@ -245,7 +254,7 @@ sub _td_start {
        my $style = $node->attr('style') || '';  
        if($style) {
           my @styles = split ';', $style;
-          my $td_w;  my $td_bg; my $back_color = "";  my $td_width = "";
+          my $td_w;  my $td_bg; my $td_a; my $back_color = "";  my $td_width = "";
           foreach my $s (@styles) {
              if($s =~ /background-color/) {
                     $td_bg = $s;
@@ -253,12 +262,20 @@ sub _td_start {
              elsif($s =~ /width/) {
                 $td_w = $s;
              }
+            elsif($s =~ /text-align/) {
+                $td_a = $s;
+             }
           }
           $back_color = $self->_extract_style_value($td_bg, 'background-color') if $td_bg;
 
           $td_width = $self->_extract_style_value($td_w, 'width') if $td_w;
+          
+          if(($align eq 'L') && ($td_a = $self->_extract_style_value($td_a, 'text-align'))) {
+                   $td_a =~ /^(\w)\w+/; 
+                   $align = uc($1);
+          }
 
-           if($back_color || $td_width) {
+           if($back_color || $td_width || $align) {
                $td_backcolor = " #$align" . $back_color . $td_width . '# ';
            }
        }
@@ -543,7 +560,7 @@ sub _code_types {
     $text =~ s/[\\]{2}/\n/g;   # required for IE which places <br> at end of each line
     $text =~ s/\n/$NL_marker\n/gms;
 
-  #  $text =~ s/[\/]*&lt;([\/]{2,2})*/fckgOpenPAREN/gms;       # substitution for open angle bracket
+  
     $text =~ s/&lt;/fckgOpenPAREN/gms;       # substitution for open angle bracket
     $text =~ s/\/\*/fckgOpen_C_COMMENT/gms;   
     $text =~ s/\*\//fckgClosed_C_COMMENT/gms;   
@@ -556,8 +573,7 @@ sub _code_types {
 
     return "" if ! $text;  
     $self->{'code'} = 1;
-    return "$NL_marker\n<code>$NL_marker\nfckgCodeBLOCK  $text $NL_marker\n</code>\n"; 
-
+    return "$NL_marker\n<code>${NL_marker}\n$text $NL_marker\n</code>\n"; 
 }
 
 
@@ -727,24 +743,28 @@ sub _dwimage_markup {
   my ($self, $src, $align) = @_;
   if($src !~ /^http:/) {
       $src =~ s/\//:/g;   
-      if($src !~ /:/) {
+      if($src !~ /^:/) {
          $src = ":$src";
       }
   }
 
       if($align eq 'center') { 
-         return "\n<align center>\n{{$src}}\n</align>\n";
+         return "\n<align center>\n{{ $src }}\n</align>\n";
       }
       if($align eq 'right') {
-       return "<align right>\n{{$src}} </align>";
+       return "<align right>\n{{ $src}} </align>";
       }
       if($align eq 'left') {
-       return "<align left>\n{{$src}}</align>";
+       return "<align left>\n{{$src }}</align>";
       }
      if($align =~ /\d+px/) {
        return "<align $align>\n{{$src}}\n</align>";
       }
 
+     if($align =~ /bottom|baseline/) {
+       return "<align $align>\n{{$src}}\n</align>";
+      }
+    
    return "{{$src}}   ";
 }
 
@@ -778,17 +798,19 @@ sub _image {
    if($src =~ /editor\/images\/smiley\/msn/) {
         if($src =~ /media=(http:.*?\.gif)/) {
               $src = $1;
+
         }
        else {
             my $HOST = $self->base_uri;
             $src = 'http://' . $HOST . $src if($src !~ /$HOST/);
+
        }
 
         return "{{$src}}   ";
    }
 
 
-   if($src !~ /userfiles\/image/) {
+   if($src !~ /userfiles\/image/  && $src !~ /\/data\/media/) {
          my @elems = split /=/, $src;
          $src = pop @elems;
          return $self->_dwimage_markup($src,$alignment) if($src !~ /^http:/);
@@ -800,6 +822,10 @@ sub _image {
          return $self->_dwimage_markup($src,$alignment);
    }
 
+   if($src =~ s/^(.*?)\/data\/media\///) {
+         return $self->_dwimage_markup($src,$alignment);
+   }
+
     my $img_url = $self->SUPER::_image($node, $rules);
 
     $img_url =~ s/%25/%/g;
@@ -825,6 +851,11 @@ sub _image {
 
 sub _image_alignment {
   my ($self, $node) = @_;
+  my $align = $node->attr('align') || "";
+  if($align) {
+     $align = 'center' if $align eq 'middle';
+     return $align;  
+  }
   if($node->parent) {
     my $p = $node->parent;
     my %atts = $p->all_external_attr();
@@ -838,6 +869,10 @@ sub _image_alignment {
            elsif($atts{$at} =~ /text-align:\s+(\w+)/) {
                  return $1;
            }
+           elsif($atts{$at} =~ /bottom|base/) {
+                 return 'bottom';
+           }
+
         }
      } 
   }
@@ -865,6 +900,23 @@ sub _link {
 
     my $internal_link = "";
     my $_text = $self->get_elem_contents($node) || "";
+   
+# these manage shares
+   if($url =~ /file:/) {
+        $url =~ s/^file:[\/]+/__SHARE__/;
+        $url =~ s/\//\\/g;
+        $self->{'share'} = 1;
+        return "[[$url|$_text]]";
+   }
+   elsif($url =~/[\\]{2,}/) {
+        $url =~ s/^[\/]+//;
+        $url =~ s/^[\\]+/__SHARE__/;
+        $_text = $url if(!$_text);
+        $_text =~ s/\\{2,}/\\/g; 
+
+        $self->{'share'} = 1;
+        return "[[$url|$_text]]";
+    }
 
     if($name) {
          return '~~ANCHOR:' . $name . ':::' . $_text .'~~';
@@ -1061,11 +1113,34 @@ sub _block {
    return $block . $text . '</block><br />';
 
 }
+   sub _table {
+     my($self, $node, $rules ) = @_;
+     my $text = $self->get_elem_contents($node) || "";
+ 
+     my $table_header = "";
+     my $align = $node->attr('align');
+     if($align) {
 
+       if($text=~/$NL_marker(.*?)$NL_marker/gms) {  
+           my $row   = $1;  
+           my @cols = $row=~/[\|\^]/g;
+           my $cols = scalar @cols;    
+           if($cols) {
+             $cols--;
+             $table_header = $NL_marker . "|++THEAD++ ALIGN=$align" .  '|' x $cols ;  
+          }
+       }
+     }
+        
+   #  return "<align left></align>${table_header}$text<align left><br /></align>";
+  return "<align left></align>${table_header}$text<align left></align>++END_TABLE++";
+     
+   }
 
    sub  postprocess_output {
     
       my($self, $outref ) = @_;  
+
       $$outref =~ s/^[\s\xa0]+//;          # trim  
             $$outref =~ s/[\s\xa0]+$//;
             $$outref =~ s/\n{2,}/\n/g;     # multi
@@ -1114,7 +1189,9 @@ sub _block {
          $$outref =~ s/<font _dummy_\/courier New>\s*<\/font>//gms;
 
          $$outref =~ s/([\/\{]{2})*(\s*)(?<!\[\[)\s*(http:\/\/[_\p{IsDigit}\p{IsAlpha}\p{IsXDigit};&?:.\-='"\/]{7,})(?!\|)/$self->_clean_url($3,$1, $2)/egms;   
- 
+
+         $$outref =~ s/__SHARE__/\\\\/gms if $self->{'share'}; 
+
          $$outref =~s/$EOL//g;
 
          $$outref =~ s/<code><\/code>//gms;
@@ -1140,7 +1217,7 @@ sub _block {
         if($self->{'code'}) {            
            $$outref =~ s/x\00/ /gms;
            $$outref =~ s/(?<=<code>)(.*?)(?=<\/code>)/$self->fix_code($1)/gmse;
-          # $$outref =~ s/<\/code>/<\/code><br \/>/gm;
+           $$outref =~ s/<\/code>[\s\n]*$/<\/code><br \/>/;          
        }
 
        $$outref =~ s/<\/block>/<\/block><align left><\/align>/gm if $self->{'block'};         
@@ -1149,6 +1226,13 @@ sub _block {
        if($$outref !~ /<align|<fckg.*?fckg>/gms) {
            $$outref = '<fckg></fckg>' . $$outref;
        }
+      
+     
+      if($self->{'in_table'}) { 
+         $$outref =~ s/\+\+END_TABLE\+\+[\s\n]*$/<br \/>/;
+         $$outref =~ s/\++END_TABLE\+\+//g;
+      }
+
     }
 
 
@@ -1183,7 +1267,7 @@ sub _block {
 
     sub _clean_url {
       my($self,$url, $markup, $spaces) = @_;
-      return $url if $url=~/editor\/images\/smiley\/msn/; 
+      return "{{$url" if $url=~/editor\/images\/smiley\/msn/; 
 
       if($markup =~/\{\{/) {   ## an external image, the first pair of brackets have been removed by regex
          return $markup . $spaces . $url;
